Closes # .

# Code Checklist

Ensure the following tasks are completed.

- [ ] Is dependencies added with `poetry add`?
- [ ] Is the README.md updated?
- [ ] Are tests included?
- [ ] Are the tests running?
- [ ] Are the names of the files correct?
- [ ] Are migrations included? `make makemigrations && make migrate`
- [ ] Does `make up` work?
- [ ] Does `helm template show ./charts/opszero` work?
- [ ] Add PR/Issue to opsZero Project and set to `Review` column

# Reviewer Checklist

- [ ] Go through https://docs.opszero.com/intro.html#pull-request-checklist

# Business Checklist

- [ ] Is the marketing landing page updated?
- [ ] Is the sales proposal updated?
- [ ] Is the documentation updated?